Index: third_party/protobuf/src/google/protobuf/util/message_differencer_unittest.proto |
diff --git a/third_party/protobuf/src/google/protobuf/unittest_mset.proto b/third_party/protobuf/src/google/protobuf/util/message_differencer_unittest.proto |
similarity index 61% |
copy from third_party/protobuf/src/google/protobuf/unittest_mset.proto |
copy to third_party/protobuf/src/google/protobuf/util/message_differencer_unittest.proto |
index 3497f09fa6d41b7b38357e7f2610dfb5c087d3e4..698775f14cc4706550b82a34c9ec063b0612a1c0 100644 |
--- a/third_party/protobuf/src/google/protobuf/unittest_mset.proto |
+++ b/third_party/protobuf/src/google/protobuf/util/message_differencer_unittest.proto |
@@ -1,6 +1,6 @@ |
// Protocol Buffers - Google's data interchange format |
// Copyright 2008 Google Inc. All rights reserved. |
-// http://code.google.com/p/protobuf/ |
+// https://developers.google.com/protocol-buffers/ |
// |
// Redistribution and use in source and binary forms, with or without |
// modification, are permitted provided that the following conditions are |
@@ -32,41 +32,43 @@ |
// Based on original Protocol Buffers design by |
// Sanjay Ghemawat, Jeff Dean, and others. |
// |
-// This file contains messages for testing message_set_wire_format. |
+// This file contains messages for testing repeated field comparison |
+syntax = "proto2"; |
package protobuf_unittest; |
option optimize_for = SPEED; |
-// A message with message_set_wire_format. |
-message TestMessageSet { |
- option message_set_wire_format = true; |
- extensions 4 to max; |
-} |
- |
-message TestMessageSetContainer { |
- optional TestMessageSet message_set = 1; |
-} |
- |
-message TestMessageSetExtension1 { |
- extend TestMessageSet { |
- optional TestMessageSetExtension1 message_set_extension = 1545008; |
- } |
- optional int32 i = 15; |
-} |
+message TestField { |
+ optional int32 a = 3; |
+ optional int32 b = 4; |
+ optional int32 c = 1; |
+ repeated int32 rc = 2; |
+ optional TestField m = 5; |
-message TestMessageSetExtension2 { |
- extend TestMessageSet { |
- optional TestMessageSetExtension2 message_set_extension = 1547769; |
+ extend TestDiffMessage { |
+ optional TestField tf = 100; |
} |
- optional string str = 25; |
} |
-// MessageSet wire format is equivalent to this. |
-message RawMessageSet { |
+message TestDiffMessage { |
repeated group Item = 1 { |
- required int32 type_id = 2; |
- required bytes message = 3; |
+ optional int32 a = 2; // Test basic repeated field comparison. |
+ optional string b = 4; // Test basic repeated field comparison. |
+ repeated int32 ra = 3; // Test SetOfSet Comparison. |
+ repeated string rb = 5; // Test TreatAsMap when key is repeated |
+ optional TestField m = 6; // Test TreatAsMap when key is a message |
+ repeated TestField rm = 7; // Test TreatAsMap when key is a repeated |
+ // message |
} |
+ |
+ optional int32 v = 13 [deprecated = true]; |
+ optional string w = 14; |
+ optional TestField m = 15; |
+ repeated int32 rv = 11; // Test for combinations |
+ repeated string rw = 10; // Test for combinations |
+ repeated TestField rm = 12 [deprecated = true]; // Test for combinations |
+ |
+ extensions 100 to 199; |
} |